@@ -7,7 +7,9 @@ import os
 from pathlib import Path, PureWindowsPath
 import re
 import time
+import math
 from typing import List
+import random
 
 import numpy as np
 import PIL.Image
@@ -82,6 +84,46 @@ def replace_str_index(text:str,index:int,replacement:str='_'):
     """
     return '%s%s%s'%(text[:index],replacement,text[index+1:])
 
+def random_color(range:int=1)->np.array:
+    """Generate random color (either [0-1] or [0-255]).\n
+
+    Args:
+        range (int, optional): 1 or 255. Defaults to 1.
+
+    Raises:
+        ValueError: Range should be either 1 or 255.
+
+    Returns:
+        np.array[3x1]
+    """
+    color=np.array([random.randint(0, 255),random.randint(0, 255),random.randint(0, 255)])
+    if int(range)==255:
+        pass
+    elif int(range)==1:
+       color=color/255
+    else:
+        raise ValueError('Range should be either 1 or 255.')
+    return color
+
+def split_list(list, n:int=None,l:int=None):
+    """Split list into approximately equal chunks. Last list might have an unequal number of elements.
+
+    Args:
+        list (object): list to split.\n.
+        n (int,optional): number of splits.\n
+        l:(int,optional): length of each chunk.\n
+
+    Returns:
+        List[List]: 
+    """
+    if n:
+        k, m = divmod(len(list), n)
+        return [list[i*k+min(i, m):(i+1)*k+min(i+1, m)] for i in range(n)]
+    elif l:
+        n=int(math.ceil(len(list)/l))
+        return [list[i*l:(i+1)*l] for i in range(n)]
+    else:
+        raise ValueError('No input provided. Enter n or l.')
 
 def get_folder_path(path :str) -> str:
     """Returns the folderPath.
