@@ -43,8 +43,10 @@ class TestNode(unittest.TestCase):
         cls.xcr=rdflib.Namespace('http://www.w3.org/1999/02/22-rdf-syntax-ns#')
         cls.ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
         
+        cls.bimGraphPath = cls.path / 'sampleBimGraph.ttl'
+
         #IFC1 (IfcWall)
-        cls.bimGraphPath1=cls.path / 'bimGraph1.ttl'
+        cls.bimGraphPath1= cls.bimGraphPath #cls.path / 'bimGraph1.ttl'
         cls.bimGraph1=Graph().parse(cls.bimGraphPath1)
         cls.ifcPath1=cls.path / 'IFC' / "Academiestraat_building_1.ifc"  
         cls.ifc1=ifcopenshell.open(str(cls.ifcPath1))   
@@ -54,7 +56,7 @@ class TestNode(unittest.TestCase):
         cls.subject1=next(s for s in cls.bimGraph1.subjects(RDF.type) if "file:///Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d" in s.toPython())
         
         #IFC2 (IfcSite)
-        cls.bimGraphPath2=cls.path / 'bimGraph2.ttl'
+        cls.bimGraphPath2= cls.bimGraphPath #cls.path / 'bimGraph2.ttl'
         cls.bimGraph2=Graph().parse(cls.bimGraphPath2)
         cls.ifcPath2=cls.path / 'IFC' / "Mariakerke_AWV_Conform_3D_BT_l72.ifc"
         cls.ifc2=ifcopenshell.open(str(cls.ifcPath2))   
@@ -64,7 +66,7 @@ class TestNode(unittest.TestCase):
         cls.subject2=next(s for s in cls.bimGraph2.subjects(RDF.type) if "file:///BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz" in s.toPython())
         
         #IFC3 (IfcSlab)
-        cls.bimGraphPath3= cls.path / 'bimGraph3.ttl'
+        cls.bimGraphPath3= cls.bimGraphPath #cls.path / 'bimGraph3.ttl'
         cls.bimGraph3=Graph().parse(cls.bimGraphPath3)
         cls.ifcPath3= cls.path / 'IFC' / "Academiestraat_parking.ifc"
         cls.ifc3=ifcopenshell.open(str(cls.ifcPath3))   
@@ -74,7 +76,7 @@ class TestNode(unittest.TestCase):
         cls.subject3=next(s for s in cls.bimGraph3.subjects(RDF.type) if "file:///174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp" in s.toPython())
         
         #IFC4 (IfcDoor)
-        cls.bimGraphPath4= cls.path / 'bimGraph4.ttl'
+        cls.bimGraphPath4= cls.bimGraphPath #cls.path / 'bimGraph4.ttl'
         cls.bimGraph4=Graph().parse(cls.bimGraphPath4)
         cls.ifcPath4= cls.path / 'IFC' / "B1_ALG_Model.ifc"
         cls.ifc4=ifcopenshell.open(str(cls.ifcPath4))   
@@ -157,12 +159,12 @@ class TestNode(unittest.TestCase):
         #path2 with getResource
         node= BIMNode(path=self.path2,getResource=True)        
         self.assertEqual(node.name,ut.get_filename(self.path2))
-        self.assertEqual(node.faceCount,len(self.mesh2.triangles))
+        self.assertIsNotNone(node._resource)
 
         #path3 
         node= BIMNode(path=self.path3,getResource=True)
         self.assertEqual(node.name,ut.get_filename(self.path3))
-        self.assertEqual(node.faceCount,len(self.mesh3.triangles))
+        self.assertIsNotNone(node._resource)
 
     def test_bimnode_creation_from_ifcpath(self):
         #path1 without extra info -> take first IfcElement
@@ -250,7 +252,7 @@ class TestNode(unittest.TestCase):
     def test_node_creation_with_get_resource(self):
         #mesh
         node= BIMNode(resource=self.mesh1)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
         #path without getResource
         node= BIMNode(path=self.path2)
@@ -266,7 +268,7 @@ class TestNode(unittest.TestCase):
         
         #graphPath with get resource
         node= BIMNode(subject=self.subject3,graphPath=self.bimGraphPath3,getResource=True)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
     def test_clear_resource(self):
         #mesh
