@@ -17,7 +17,7 @@ import pytest
 from ifcopenshell.util.selector import Selector
 from rdflib import Graph
 
- ################################## SETUP/TEARDOWN MODULE ######################
+################################## SETUP/TEARDOWN MODULE ######################
 
 # def setUpModule():
 #     #execute once before the module 
@@ -181,32 +181,6 @@ class TestGeometryutils(unittest.TestCase):
         identityPointCloud2, indentityArray2=gt.create_identity_point_cloud(list)
         self.assertEqual(len(identityPointCloud2.points),len(indentityArray2))
 
-    def test_create_visible_point_cloud_from_meshes(self):
-        referenceMesh1= copy.deepcopy(self.slabMesh)
-        referenceMesh1.translate([1,0,0])
-        referenceMesh2= copy.deepcopy(self.slabMesh)
-        referenceMesh2.translate([0,1,0])
-        
-        # 1 geometry
-        identityPointClouds1, percentages1=gt.create_visible_point_cloud_from_meshes(geometries=self.slabMesh,
-                                                references=referenceMesh1)
-        self.assertEqual(len(identityPointClouds1),1)
-        self.assertGreater(len(identityPointClouds1[0].points),10)
-        self.assertEqual(len(percentages1),1)        
-        self.assertLess(percentages1[0],0.2)
-
-        # multiple geometries 
-        list=[self.slabMesh,self.wallMesh]
-        references=[referenceMesh1,referenceMesh2]
-        identityPointClouds2, percentages2=gt.create_visible_point_cloud_from_meshes(geometries=list,
-                                                references=references)
-        self.assertEqual(len(identityPointClouds2),2)
-        self.assertLess(len(identityPointClouds2[0].points),len(identityPointClouds1[0].points))
-        self.assertEqual(len(percentages2),2)        
-        self.assertLess(percentages2[0],percentages1[0])
-    
-        
-
     def test_cap_mesh(self):
         print('test_cap_mesh NOT IMPLEMENTED')
         self.assertEqual(0,0)
@@ -342,26 +316,7 @@ class TestGeometryutils(unittest.TestCase):
         pcd=gt.mesh_to_pcd(self.mesh)
         self.assertIsInstance(pcd,o3d.geometry.PointCloud)
         self.assertGreater(len(pcd.points),3)
-        
-#    def test_generate_virtual_images(self):
-#        cartesianTransforms= [self.image1CartesianTransform,self.image2CartesianTransform]
-#        image=gt.generate_virtual_images(self.mesh, cartesianTransforms)
-#        self.assertEqual(len(image),2)
-#        self.assertIsInstance(image[0],o3d.cpu.pybind.geometry.Image)
-        
-#    def test_generate_virtual_image(self):
-#        width=640
-#        height=480
-#        fx=400
-#        fy=400
-#        cx=width/2-0.5
-#        cy=height/2-0.5
-#        pinholeCamera=o3d.camera.PinholeCameraParameters
-#        pinholeCamera.extrinsic=np.linalg.inv(self.image1CartesianTransform)
-#        pinholeCamera.intrinsic=o3d.camera.PinholeCameraIntrinsic(width,height,fx,fy,cx,cy)
-#        image=gt.generate_virtual_image(self.mesh, pinholeCamera)
-#        self.assertIsInstance(image,o3d.cpu.pybind.geometry.Image)
-        
+ 
     def test_e57path_to_pcd(self):
         e57=pye57.E57(str(self.e57Path1)) 
         header = e57.get_header(0)
@@ -450,9 +405,6 @@ class TestGeometryutils(unittest.TestCase):
         mesh=gt.get_mesh_representation(self.pcd)
         self.assertGreater(len(mesh.triangles),3)
 
-        #invalid input
-        self.assertRaises(ValueError,gt.get_mesh_representation,self.mesh.get_oriented_bounding_box())
-
     def test_get_mesh_inliers(self):
         #mesh
         sources=[self.slabMesh,self.wallMesh]
@@ -464,9 +416,6 @@ class TestGeometryutils(unittest.TestCase):
         indices=gt.get_mesh_inliers(sources=sources,reference=self.pcd)
         self.assertEqual(len(indices),len(sources))
 
-        #invalid sources
-        self.assertRaises(ValueError,gt.get_mesh_inliers,self.mesh.get_oriented_bounding_box(),self.mesh.get_oriented_bounding_box())
-
     def test_expand_box(self):
         cartesianBounds=np.array([0,10,7,8.3,-2,2])       
         box=gt.get_oriented_bounding_box(cartesianBounds)
@@ -507,45 +456,25 @@ class TestGeometryutils(unittest.TestCase):
         sourceMesh=self.mesh
         cutterMeshes=[self.slabMesh,self.wallMesh,self.columnMesh,self.beamMesh]
         # mesh + [mesh]
-        result1=gt.crop_geometry_by_distance(source=sourceMesh,cutters=cutterMeshes)
+        result1=gt.crop_geometry_by_distance(source=sourceMesh,reference=cutterMeshes)
         self.assertGreater(len(result1.vertices),1900 )
 
         # pcd + [mesh]
-        result2=gt.crop_geometry_by_distance(source=sourcepcd,cutters=cutterMeshes)
+        result2=gt.crop_geometry_by_distance(source=sourcepcd,reference=cutterMeshes)
         self.assertGreater(len(result2.points),350000 ) 
 
         # mesh + pcd
-        result3=gt.crop_geometry_by_distance(source=sourceMesh,cutters=sourcepcd)
+        result3=gt.crop_geometry_by_distance(source=sourceMesh,reference=sourcepcd)
         self.assertGreater(len(result3.vertices),5000 ) 
 
         # pcd + mesh
-        result4=gt.crop_geometry_by_distance(source=sourcepcd,cutters=sourceMesh)
+        result4=gt.crop_geometry_by_distance(source=sourcepcd,reference=sourceMesh)
         self.assertLess(len(result4.points),1200000 ) 
     
-    def test_determine_percentage_of_coverage(self):
-        reference=self.pcd
-        sources=[self.slabMesh,self.wallMesh,self.columnMesh,self.beamMesh]
-        percentages=gt.determine_percentage_of_coverage(sources=sources,reference=reference)
-        self.assertEqual(len(percentages), len(sources))
-        self.assertLess(percentages[0],0.005)
-        self.assertLess(percentages[1],0.001)
-        self.assertLess(percentages[2],0.5)
-        self.assertLess(percentages[3],0.001)
-
-    def test_show_geometries(self):
-        # gt.show_geometries((self.bimMeshes + [self.pcd, self.mesh]), color = True)
-        self.assertEqual(0,0)
-        
     def test_create_3d_camera(self):
         cam=gt.create_3d_camera()
         self.assertIsInstance(cam,o3d.geometry.TriangleMesh)
         
-    # def test_save_view_point(self):
-    #     print("test_save_view_point")
-    #     filename=os.path.join(self.resourcePath,'myView.png')
-    #     gt.save_view_point(self.pcd, filename)
-    #     self.assertTrue(os.path.exists(filename))
-
     def test_crop_geometry_by_convex_hull(self):
         sourceMesh=gt.mesh_to_trimesh(self.mesh)
         meshes=[self.slabMesh,self.wallMesh,self.columnMesh,self.beamMesh]
@@ -561,20 +490,6 @@ class TestGeometryutils(unittest.TestCase):
         outerCrop=gt.crop_mesh_by_convex_hull(source=sourceMesh, cutters=cutters[0], inside = False ) 
         self.assertGreater(len(outerCrop[0].vertices),255000)         
         
-#    def test_crop_geometry_by_raycasting(self):
-#        pcd=self.pcd
-#        mesh=self.mesh
-#        hull, _ = pcd.compute_convex_hull()
-#
-#        innerCrop=gt.crop_geometry_by_raycasting(source=mesh, cutter=hull, inside=True, strict =True ) 
-#        self.assertLess(len(innerCrop.vertices),200000 )
-#
-#        innerCrop=gt.crop_geometry_by_raycasting(source=mesh, cutter=hull, inside=True, strict =False ) 
-#        self.assertLess(len(innerCrop.vertices),200000 )
-#
-#        outerCrop=gt.crop_geometry_by_raycasting(source=mesh, cutter=hull, inside=False, strict =True ) 
-#        self.assertLess(len(outerCrop.vertices),200000 )
-        
     def test_get_translation(self):
         box=self.mesh.get_oriented_bounding_box()
         centerGt=box.get_center()
@@ -592,22 +507,8 @@ class TestGeometryutils(unittest.TestCase):
         #cartesianTransform
         center=gt.get_translation(self.image2CartesianTransform)
         self.assertAlmostEqual(self.image2CartesianTransform[0][3],center[0],delta=0.01)
-
-    def test_get_mesh_collisions_open3d(self):
-        #NOT IMPLEMENTED
-        pass
-        # meshes=[self.slabMesh,self.wallMesh,self.columnMesh,self.beamMesh]
-        # slabCollisions= gt.get_mesh_collisions_open3d(sourceMesh=self.slabMesh, meshes=meshes,t_d=0.5)
-        # self.assertEqual(len(slabCollisions),23)
-
-        # wallCollisions= gt.get_mesh_collisions_open3d(sourceMesh=self.wallMesh, meshes=self.bimBoxes)
-        # self.assertEqual(len(wallCollisions),1)
-
-        # ColumnCollisions= gt.get_mesh_collisions_open3d(sourceMesh=self.columnMesh, meshes=self.bimBoxes)
-        # self.assertEqual(len(ColumnCollisions),23)
        
     def test_get_mesh_collisions_trimesh(self):
-
         inliers=gt.get_mesh_collisions_trimesh(sourceMesh=self.mesh , geometries =self.bimMeshes) 
         self.assertEqual(len(inliers),66 )
 
@@ -638,9 +539,9 @@ class TestGeometryutils(unittest.TestCase):
         self.assertAlmostEqual(r4[0][0],rotationGt[0][0], delta=0.01)
 
     def test_mesh_to_trimesh(self):
-        triMesh=gt.mesh_to_trimesh(self.mesh)
+        triMesh=gt.mesh_to_trimesh(self.slabMesh)
         mesh2=triMesh.as_open3d
-        self.assertEqual(len(self.mesh.triangles),len(mesh2.triangles))
+        self.assertEqual(len(self.slabMesh.triangles),len(mesh2.triangles))
 
 if __name__ == '__main__':
     unittest.main()
