@@ -45,7 +45,7 @@ class TestNode(unittest.TestCase):
         cls.ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
        
         #IMGGRAPH
-        cls.imgGraphPath= cls.path / 'imgGraph.ttl'
+        cls.imgGraphPath= cls.path / 'sampleImgGraph.ttl' #cls.path / 'imgGraph.ttl'
         cls.imgGraph=Graph().parse(cls.imgGraphPath)
 
         #IMG1 (image)
