@@ -58,25 +58,25 @@ class TestLinkeddatatools(unittest.TestCase):
         cls.imgXmlPath2=os.path.join(cls.path,'IMG',"ReferenceLAMBERT08_TAW.xml")  
         
         #IFC1
-        cls.bimGraphPath1=os.path.join(cls.path,'bimGraph1.ttl')
+        cls.bimGraphPath1= os.path.join(cls.path,'sampleBimGraph.ttl') #os.path.join(cls.path,'bimGraph1.ttl')
         # cls.bimGraph1=Graph().parse(cls.bimGraphPath1)
         cls.ifcPath1=os.path.join(cls.path,'IFC',"Academiestraat_building_1.ifc")  
         # cls.ifc1=ifcopenshell.open(cls.ifcPath1)   
         
         #IFC2 
-        cls.bimGraphPath2=os.path.join(cls.path,'bimGraph2.ttl')
+        cls.bimGraphPath2= os.path.join(cls.path,'sampleBimGraph.ttl') #os.path.join(cls.path,'bimGraph2.ttl')
         # cls.bimGraph2=Graph().parse(cls.bimGraphPath2)
         cls.ifcPath2=os.path.join(cls.path,'IFC',"Mariakerke_AWV_Conform_3D_BT_l72.ifc")  
         # cls.ifc2=ifcopenshell.open(cls.ifcPath2)  
 
         #IFC3 
-        cls.bimGraphPath3=os.path.join(cls.path,'bimGraph3.ttl')
+        cls.bimGraphPath3= os.path.join(cls.path,'sampleBimGraph.ttl') #os.path.join(cls.path,'bimGraph3.ttl')
         # cls.bimGraph3=Graph().parse(cls.bimGraphPath3)
         cls.ifcPath3=os.path.join(cls.path,'IFC',"Academiestraat_parking.ifc")  
         # cls.ifc3=ifcopenshell.open(cls.ifcPath3)   
         
         #IFC4 (IfcDoor)
-        cls.bimGraphPath4=os.path.join(cls.path,'bimGraph4.ttl')
+        cls.bimGraphPath4= os.path.join(cls.path,'bimGraph4.ttl')
         # cls.bimGraph4=Graph().parse(cls.bimGraphPath4)
         cls.ifcPath4=os.path.join(cls.path,'IFC',"B1_ALG_Model.ifc")  
         # cls.ifc4=ifcopenshell.open(cls.ifcPath4)   
@@ -86,9 +86,6 @@ class TestLinkeddatatools(unittest.TestCase):
         # cls.resourceGraph=Graph().parse(cls.resourceGraphPath)
         # cls.linkedSubjects=[s for s in cls.resourceGraph.subjects(RDF.type)]
 
-        #BIMGRAPH
-        cls.bimGraphPath1=os.path.join(cls.path,'bimGraph1.ttl')
-
         #RESOURCES
         cls.resourcePath=os.path.join(cls.path,"resources")
         if not os.path.exists(cls.resourcePath):
@@ -324,7 +321,7 @@ class TestLinkeddatatools(unittest.TestCase):
     def test_select_k_nearest_nodes(self):
         nodes=ld.graph_path_to_nodes(graphPath=self.bimGraphPath1,getResource=True)
         list,distances=ld.select_k_nearest_nodes(nodes[0],nodes)
-        self.assertEqual(len(list),10)
+        self.assertEqual(len(list),4)
 
         #error k<=0
         self.assertRaises(ValueError,ld.select_k_nearest_nodes,node=nodes[0],nodelist=nodes,k=-5 )
@@ -332,7 +329,7 @@ class TestLinkeddatatools(unittest.TestCase):
     def test_select_nodes_with_centers_in_radius(self):
         nodes=ld.graph_path_to_nodes(graphPath=self.bimGraphPath2,getResource=True)
         list,distances=ld.select_nodes_with_centers_in_radius(nodes[0],nodes,r=10)
-        self.assertEqual(len(list),2)
+        self.assertEqual(len(list),1)
         for d in distances:
             self.assertLess(d,10)
 
@@ -343,7 +340,7 @@ class TestLinkeddatatools(unittest.TestCase):
     def test_select_nodes_with_centers_in_bounding_box(self): 
         nodes=ld.graph_path_to_nodes(graphPath=self.bimGraphPath3,getResource=True)
         list=ld.select_nodes_with_centers_in_bounding_box(nodes[0],nodes,u=5,v=5,w=5)
-        self.assertEqual(len(list),2)
+        self.assertEqual(len(list),1)
 
         # no nodes
         node=nodes[0]
@@ -367,7 +364,7 @@ class TestLinkeddatatools(unittest.TestCase):
         nodes = ld.graph_path_to_nodes(graphPath=self.resourceGraphPath,getResource=True)
         self.assertEqual(len(nodes),4)
         nodes.extend(ld.graph_path_to_nodes(graphPath=self.bimGraphPath3,getResource=True))
-        self.assertEqual(len(nodes),104)
+        self.assertEqual(len(nodes),8)
 
         list= ld.select_nodes_with_intersecting_resources(nodes[0],nodes)
         print(list)
@@ -377,7 +374,8 @@ class TestLinkeddatatools(unittest.TestCase):
         nodes=ld.graph_path_to_nodes(graphPath=self.resourceGraphPath,getResource=True)        
         for n in nodes:
             geometry=ld.get_mesh_representation(n)
-            self.assertTrue('TriangleMesh' in str(type(geometry)))
+            if(geometry is not None):
+                self.assertTrue('TriangleMesh' in str(type(geometry)))
 
 
 if __name__ == '__main__':
